ServiceResponse

Struct ServiceResponse 

pub struct ServiceResponse<M: Message> {
    pub version: Version,
    pub headers: HeaderMap,
    pub status: StatusCode,
    pub output: M,
}
A response with HTTP info and the output object as a protobuf Message.

Fields

version: Version

The HTTP version

headers: HeaderMap

The set of headers

Should always at least have Content-Type. Servers will override Content-Length on serialization.

status: StatusCode

The status code

output: M

The output object

Implementations

Source

impl<M: Message> ServiceResponse<M>

pub fn new(output: M) -> ServiceResponse<M>

Create new service request with the given input object

This automatically sets the Content-Type header as application/protobuf.

pub fn clone_with_output(&self, output: M) -> ServiceResponse<M>

Copy this response with a different output value

Source

impl<M: Message + Default> ServiceResponse<M>

pub async fn from_hyper_response( resp: Response<Body>, ) -> Result<Self, ProstTwirpError>

Deserialze an object response from a hyper response.

pub fn to_hyper_response(&self) -> Result<Response<Body>, ProstTwirpError>

Serialize an object response into a hyper response.