pub struct ServiceRequest<T: Message> {
pub uri: Uri,
pub method: Method,
pub version: Version,
pub headers: HeaderMap,
pub input: T,
}Expand description
A request with HTTP info and a proto request payload object.
Fields
uri: UriThe URI of the original request
When using a client, this will be overridden with the proper URI. It is only valuable for servers.
method: MethodThe request method; should always be POST.
version: VersionThe HTTP version, rarely changed from the default.
headers: HeaderMapThe set of headers
Should always at least have Content-Type. Clients will override Content-Length on serialization.
input: TThe request body as a proto Message, representing the arguments of the proto rpc.
Implementations
Sourceimpl<T: Message> ServiceRequest<T>
impl<T: Message> ServiceRequest<T>
Sourcepub fn new(input: T) -> ServiceRequest<T>
pub fn new(input: T) -> ServiceRequest<T>
Create new service request with the given input object
This automatically sets the Content-Type header as application/protobuf.
Sourcepub fn clone_with_input(&self, input: T) -> ServiceRequest<T>
pub fn clone_with_input(&self, input: T) -> ServiceRequest<T>
Copy this request with a different input value
Sourceimpl<T: Message + Default + 'static> ServiceRequest<T>
impl<T: Message + Default + 'static> ServiceRequest<T>
Sourcepub fn to_hyper_request(&self) -> Result<Request<Body>, ProstTwirpError>
pub fn to_hyper_request(&self) -> Result<Request<Body>, ProstTwirpError>
Serialize into a hyper request.
pub async fn from_hyper_request( req: Request<Body>, ) -> Result<ServiceRequest<T>, ProstTwirpError>